@@ -50,6 +50,7 @@ __all__ = (
     "CreateFieldRequestRequestTypeDef",
     "LayoutConfigurationTypeDef",
     "RequiredFieldTypeDef",
+    "DeleteDomainRequestRequestTypeDef",
     "DomainSummaryTypeDef",
     "RelatedItemEventIncludedDataTypeDef",
     "FieldItemTypeDef",
@@ -295,6 +296,13 @@ RequiredFieldTypeDef = TypedDict(
     },
 )
 
+DeleteDomainRequestRequestTypeDef = TypedDict(
+    "DeleteDomainRequestRequestTypeDef",
+    {
+        "domainId": str,
+    },
+)
+
 DomainSummaryTypeDef = TypedDict(
     "DomainSummaryTypeDef",
     {
